==> activity-usercenter-api-0.2.14-sources.jar: cn/com/duiba/tuia/activity/usercenter/api/remoteservice/RemoteTuiaUserService.java <==
package cn.com.duiba.tuia.activity.usercenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.activity.usercenter.api.dto.NickNameDto;
import cn.com.duiba.tuia.activity.usercenter.api.dto.consumer.ConsumerDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * Created by houwen on 26/07/2017.
 */
@AdvancedFeignClient
public interface RemoteTuiaUserService {

    /**
     * 根据APPKEY和设备ID查询, 查询不到就创建一个新用户
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> findByAppIdAndDeviceId(Long appId, String deviceId);

    /**
     * 根据APPKEY和设备ID查询
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> searchByAppIdAndDeviceId(Long appId, String deviceId);

    /**
     * 根据APPKEY和设备ID创建一个新用户
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> insertByAppIdAndDeviceId(Long appId, String deviceId);

    /**·
     * 根据media_user_id或者phone来查询用户，查询不到就创建用户
     *  [注意]此接口只提供给金币业务，会创建可登录的用户，普通活动使用findByAppIdAndDeviceId接口
     * @param consumer
     * @return 包含用户密码的用户信息集合
     */
    ConsumerDto findOrCreateConsumer(ConsumerDto consumer);

    /***
         * @Description: findConsumer 根据media_user_id或者phone来查询正式用户用户
         * 数据源tuia_consumer
         * @Param: [req]
         * @Return: cn.com.duiba.tuia.activity.center.api.dto.consumer.ConsumerDto，没有返回null
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/13
         */
    ConsumerDto findFormalConsumer(ConsumerDto req);

    /***
         * @Description: findCasualConsumer 查询临时用户是否存在
         *
         * @Param: [req]
         * @Return: cn.com.duiba.tuia.activity.center.api.dto.consumer.ConsumerDto
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/20
         */
    Long findCasualConsumer(ConsumerDto req);

    /***
         * @Description: updateConsumer 更新正式用户信息
         *
         * @Param: [req]
         * @Return: java.lang.Boolean
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/20
         */
    Boolean updateConsumer(ConsumerDto req);

    ConsumerDto getConsumerById(Long userId);

    /**
     * 获取下一个可用昵称
     * @param id 当用户已分配过昵称时，获取下一个昵称需要回传之前分配过的id，便于释放
     * @return
     */
    NickNameDto getNext(Long id);

    /**
     * 确认使用该昵称
     * @param nickName
     * @return
     */
    Boolean confirmNickName(String nickName);

    Boolean isUsedNickName(String nickName);

    Boolean insertAndUsedNickName(String nickName);

    /**
     * 用户绑定手机号
     * @param userId
     * @param phone
     * @return
     */
    Boolean bindPhone(Long userId, String phone, Long appId);
}

==> activity-usercenter-api-0.3.11-20220228.015644-1-sources.jar: cn/com/duiba/tuia/activity/usercenter/api/remoteservice/RemoteTuiaUserService.java <==
package cn.com.duiba.tuia.activity.usercenter.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.activity.usercenter.api.dto.NickNameDto;
import cn.com.duiba.tuia.activity.usercenter.api.dto.consumer.ConsumerDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * Created by houwen on 26/07/2017.
 */
@AdvancedFeignClient
public interface RemoteTuiaUserService {

    /**
     * 根据APPKEY和设备ID查询, 查询不到就创建一个新用户
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> getByAppIdAndDeviceId(Long appId, String deviceId);

    /**
     * 根据APPKEY和设备ID查询, 查询不到就创建一个新用户
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> findByAppIdAndDeviceId(Long appId, String deviceId);

    /**
     * 根据APPKEY和设备ID查询
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> searchByAppIdAndDeviceId(Long appId, String deviceId);

    /**
     * 根据APPKEY和设备ID创建一个新用户
     * 这里的都是临时用户
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    DubboResult<Long> insertByAppIdAndDeviceId(Long appId, String deviceId);

    /**·
     * 根据media_user_id或者phone来查询用户，查询不到就创建用户
     *  [注意]此接口只提供给金币业务，会创建可登录的用户，普通活动使用findByAppIdAndDeviceId接口
     * @param consumer
     * @return 包含用户密码的用户信息集合
     */
    ConsumerDto findOrCreateConsumer(ConsumerDto consumer);

    /***
         * @Description: findConsumer 根据media_user_id或者phone来查询正式用户用户
         * 数据源tuia_consumer
         * @Param: [req]
         * @Return: cn.com.duiba.tuia.activity.center.api.dto.consumer.ConsumerDto，没有返回null
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/13
         */
    ConsumerDto findFormalConsumer(ConsumerDto req);

    /***
         * @Description: findCasualConsumer 查询临时用户是否存在
         *
         * @Param: [req]
         * @Return: cn.com.duiba.tuia.activity.center.api.dto.consumer.ConsumerDto
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/20
         */
    Long findCasualConsumer(ConsumerDto req);

    /***
         * @Description: updateConsumer 更新正式用户信息
         *
         * @Param: [req]
         * @Return: java.lang.Boolean
         * @throws:
         * @author: youhaijun
         * @Date:   2017/12/20
         */
    Boolean updateConsumer(ConsumerDto req);

    ConsumerDto getConsumerById(Long userId);

    /**
     * 获取下一个可用昵称
     * @param id 当用户已分配过昵称时，获取下一个昵称需要回传之前分配过的id，便于释放
     * @return
     */
    NickNameDto getNext(Long id);

    /**
     * 确认使用该昵称
     * @param nickName
     * @return
     */
    Boolean confirmNickName(String nickName);

    Boolean isUsedNickName(String nickName);

    Boolean insertAndUsedNickName(String nickName);

    /**
     * 用户绑定手机号
     * @param userId
     * @param phone
     * @return
     */
    Boolean bindPhone(Long userId, String phone, Long appId);


    /**
     * 根据用户id获取设备id
     * @param consumerId
     * @return
     */
    ConsumerDto getDeviceId(Long consumerId);

    /**
     * 根据appId+phone 查询用户信息
     * @param req
     * @return
     */
    List<ConsumerDto> findConsumerByPhone(ConsumerDto req);

    /**
     * 根据appId和deviceId查询
     * <p>
     * 查询不到就创建一个新用户
     * <p>
     * 使用预生成的consumerId
     *
     * @param appId
     * @param deviceId
     * @return 用户ID
     */
    Long findOrInsertByAppIdAndDeviceId(Long appId, String deviceId, Long consumerId);

    void insert();
}
